import PanelCodeHighlight from '@/components/panel-code-highlight';
import { Metadata } from 'next';
import Link from 'next/link';

export const metadata: Metadata = {
    title: 'پایه'
};

export default function() {
    return (
        <div>
            <ul className="flex space-x-2 rtl:space-x-reverse">
                <li>
                    <Link href="#" className="text-primary hover:underline">
                        فرم ها
                    </Link>
                </li>
                <li className="before:content-['/'] ltr:before:mr-2 rtl:before:ml-2">
                    <span>پایه</span>
                </li>
            </ul>

            <div className="grid grid-cols-1 gap-6 pt-5 lg:grid-cols-2">
                <PanelCodeHighlight
                    title="ورودی"
                >
                    <div className="mb-5">
                        <form>
                            <input type="text" placeholder="Some Text..." className="form-input" required />
                            <button type="submit" className="btn btn-primary mt-6">
                                ارسال
                            </button>
                        </form>
                    </div>
                </PanelCodeHighlight>

                {/* type=password */}
                <PanelCodeHighlight
                    title="رمز ورود"

                >
                    <div className="mb-5">
                        <form>
                            <input type="password" placeholder="Enter Password" className="form-input" required />
                            <button type="submit" className="btn btn-primary mt-6">
                                ارسال
                            </button>
                        </form>
                    </div>
                </PanelCodeHighlight>

                {/* type=email */}
                <PanelCodeHighlight
                    title="ایمیل"

                >
                    <div className="mb-5">
                        <form>
                            <input type="email" placeholder="email@mail.com" className="form-input" required />
                            <button type="submit" className="btn btn-primary mt-6">
                                ارسال
                            </button>
                        </form>
                    </div>
                </PanelCodeHighlight>

                {/* type=url */}
                <PanelCodeHighlight
                    title="نشانی "

                >
                    <div className="mb-5">
                        <form>
                            <input type="url" placeholder="https://dummyurl.com" className="form-input" required />
                            <button type="submit" className="btn btn-primary mt-6">
                                ارسال
                            </button>
                        </form>
                    </div>
                </PanelCodeHighlight>

                {/* type=tel */}
                <PanelCodeHighlight
                    title="شماره تلفن"

                >
                    <div className="mb-5">
                        <form>
                            <input type="tel" placeholder="6-(666)-111-7777" className="form-input" required />
                            <button type="submit" className="btn btn-primary mt-6">
                                ارسال
                            </button>
                        </form>
                    </div>
                </PanelCodeHighlight>

                {/* type=search */}
                <PanelCodeHighlight
                    title="جستجو"
                >
                    <div className="mb-5">
                        <form>
                            <input type="search" placeholder="Search..." className="form-input" required />
                            <button type="button" className="btn btn-primary mt-6">
                                ارسال
                            </button>
                        </form>
                    </div>
                </PanelCodeHighlight>

                {/* type=range */}
                <PanelCodeHighlight
                    title="دامنه"

                >
                    <div className="mb-5">
                        <form>
                            <input type="range" className="w-full py-2.5" min="0" max="100" />
                        </form>
                    </div>
                </PanelCodeHighlight>

                {/* input with label */}
                <PanelCodeHighlight
                    title="لیبل دار"

                >
                    <div className="mb-5">
                        <form>
                            <label htmlFor="fullname">Full Name</label>
                            <input id="fullname" type="text" placeholder="Enter Full Name" defaultValue="Alan Green"
                                   className="form-input" />
                        </form>
                    </div>
                </PanelCodeHighlight>

                {/* form controls */}
                <PanelCodeHighlight
                    title="فرم"

                    className="lg:row-span-3"
                >
                    <div className="mb-5">
                        <form className="space-y-5">
                            <div>
                                <label htmlFor="ctnEmail">ایمیل</label>
                                <input id="ctnEmail" type="email" placeholder="name@example.com" className="form-input"
                                       required />
                            </div>
                            <div>
                                <label htmlFor="ctnSelect1">انتخاب</label>
                                <select id="ctnSelect1" className="form-select text-white-dark" required>
                                    <option>Open this select menu</option>
                                    <option>One</option>
                                    <option>Two</option>
                                    <option>Three</option>
                                </select>
                            </div>
                            <div>
                                <label htmlFor="ctnSelect2">چند انتخابی</label>
                                <select id="ctnSelect2" multiple className="form-multiselect text-white-dark" required>
                                    <option>Open this select menu</option>
                                    <option>One</option>
                                    <option>Two</option>
                                    <option>Three</option>
                                </select>
                            </div>
                            <div>
                                <label htmlFor="ctnTextarea">باکس نوشتاری</label>
                                <textarea id="ctnTextarea" rows={3} className="form-textarea"
                                          placeholder="Enter Address" required></textarea>
                            </div>
                            <div>
                                <label htmlFor="ctnFile">ارسال فایل</label>
                                <input
                                    id="ctnFile"
                                    type="file"
                                    className="rtl:file-ml-5 form-input p-0 file:border-0 file:bg-primary/90 file:px-4 file:py-2 file:font-semibold file:text-white file:hover:bg-primary ltr:file:mr-5"
                                    required
                                />
                            </div>
                            <button type="submit" className="btn btn-primary !mt-6">
                                ارسال
                            </button>
                        </form>
                    </div>
                </PanelCodeHighlight>

                {/* Form Grid Layouts */}
                <PanelCodeHighlight
                    title="فرم های کنار هم"

                >
                    <div className="mb-5">
                        <form>
                            <div className="grid grid-cols-1 justify-between gap-5 sm:flex">
                                <input type="text" placeholder="Enter First Name" className="form-input" />
                                <input type="text" placeholder="Enter Last Name" className="form-input" />
                            </div>
                            <button type="button" className="btn btn-primary mt-6">
                                ارسال
                            </button>
                        </form>
                    </div>
                </PanelCodeHighlight>

                <PanelCodeHighlight
                    title="فرم های زیر هم"
                >
                    <div className="mb-5">
                        <form>
                            <div className="grid grid-cols-1 justify-between gap-5 sm:flex">
                                <input type="text" placeholder="Enter First Name" className="form-input" />
                                <input type="text" placeholder="Enter Last Name" className="form-input" />
                            </div>
                            <button type="button" className="btn btn-primary mt-6">
                                ارسال
                            </button>
                        </form>
                    </div>
                </PanelCodeHighlight>

                <PanelCodeHighlight
                    title="گروه فرم"

                >
                    <div className="mb-5">
                        <form className="space-y-5">
                            <div>
                                <label htmlFor="groupFname">نام</label>
                                <input id="groupFname" type="text" placeholder="Enter First Name"
                                       className="form-input" />
                            </div>
                            <div>
                                <label htmlFor="groupLname">نام خانوادگی</label>
                                <input id="groupLname" type="text" placeholder="Enter Last Name"
                                       className="form-input" />
                            </div>
                            <button type="button" className="btn btn-primary !mt-6">
                                ارسال
                            </button>
                        </form>
                    </div>
                </PanelCodeHighlight>

                <PanelCodeHighlight
                    title="تنوع اندازه"
                    className="lg:col-span-2"

                >
                    <div className="mb-5">
                        <form>
                            <div className="grid grid-cols-1 gap-2 md:grid-cols-3 lg:grid-cols-4">
                                <input type="text" placeholder="Enter City" className="form-input lg:col-span-2" />
                                <input type="text" placeholder="Enter State" className="form-input" />
                                <input type="text" placeholder="Enter Zip" className="form-input" />
                            </div>
                            <button type="button" className="btn btn-primary mt-6">
                                ارسال
                            </button>
                        </form>
                    </div>
                </PanelCodeHighlight>

                {/* Helper Text */}
                <PanelCodeHighlight
                    title="بهمراه کمکی"

                >
                    <div className="mb-5">
                        <form>
                            <div>
                                <input type="text" placeholder="Enter First Name" className="form-input" />
                                <span className="text-xs text-white-dark">اسم خود را در فرم بنویسید</span>
                            </div>
                        </form>
                    </div>
                </PanelCodeHighlight>

                <PanelCodeHighlight
                    title="بهمراه کمکی"

                >
                    <div className="mb-5">
                        <form>
                            <div>
                                <input type="text" placeholder="Enter First Name" className="form-input mb-2" />
                                <span className="badge bg-primary text-xs hover:top-0">اسم خود را در فرم بنویسید</span>
                            </div>
                        </form>
                    </div>
                </PanelCodeHighlight>

                <PanelCodeHighlight
                    title="بهمراه کمکی"

                >
                    <div className="mb-5">
                        <form>
                            <div>
                                <input type="text" placeholder="Enter First Name" className="form-input mb-2" />
                                <span
                                    className="badge block bg-primary text-xs hover:top-0">اسم خود را در فرم بنویسید</span>
                            </div>
                        </form>
                    </div>
                </PanelCodeHighlight>

                <PanelCodeHighlight
                    title="بهمراه کمکی"

                >
                    <div className="mb-5">
                        <form>
                            <div>
                                <label htmlFor="Txtpassword">Password</label>
                                <input id="Txtpassword" type="password" placeholder="Enter Password"
                                       className="form-input w-3/5" />
                                <span className="text-xs text-white-dark ltr:pl-2 rtl:pr-2">حداقل 8 کاراکتر</span>
                            </div>
                        </form>
                    </div>
                </PanelCodeHighlight>

                {/* Sizing */}
                <PanelCodeHighlight
                    title="تنوع در نوشتار"
                    className="lg:col-span-2"
                >
                    <div className="mb-5">
                        <form>
                            <div className="grid grid-cols-1 gap-4 sm:grid-cols-3">
                                <div>
                                    <label htmlFor="inputLarge">بزرگ</label>
                                    <input id="inputLarge" type="text" placeholder="Large Input"
                                           className="form-input-lg form-input" />
                                </div>
                                <div>
                                    <label htmlFor="inputDefault">پیش فرض</label>
                                    <input id="inputDefault" type="text" placeholder="Default Input"
                                           className="form-input" />
                                </div>
                                <div>
                                    <label htmlFor="inputSmall">کوچک</label>
                                    <input id="inputSmall" type="text" placeholder="Small Input"
                                           className="form-input-sm form-input" />
                                </div>
                            </div>
                        </form>
                    </div>
                </PanelCodeHighlight>

                <PanelCodeHighlight
                    title="تنوع در انتخابی"
                    className="lg:col-span-2"
                >
                    <div className="mb-5">
                        <form>
                            <div className="grid grid-cols-1 gap-4 sm:grid-cols-3">
                                <div>
                                    <select className="form-select-lg form-select text-white-dark">
                                        <option>لطفا انتخاب کنید</option>
                                        <option>One</option>
                                        <option>Two</option>
                                        <option>Three</option>
                                    </select>
                                </div>
                                <div>
                                    <select className="form-select text-white-dark">
                                        <option>لطفا انتخاب کنید</option>
                                        <option>One</option>
                                        <option>Two</option>
                                        <option>Three</option>
                                    </select>
                                </div>
                                <div>
                                    <select className="form-select-sm form-select text-white-dark">
                                        <option>لطفا انتخاب کنید</option>
                                        <option>One</option>
                                        <option>Two</option>
                                        <option>Three</option>
                                    </select>
                                </div>
                            </div>
                        </form>
                    </div>
                </PanelCodeHighlight>

                <PanelCodeHighlight
                    title="فرم های افقی"
                >
                    <div className="mb-5">
                        <form className="space-y-5">
                            <div className="items-center justify-between gap-5 sm:flex md:gap-20">
                                <label htmlFor="hrLargeinput">ایمیل</label>
                                <input id="hrLargeinput" type="email" placeholder="name@example.com"
                                       className="form-input py-2.5 text-base" />
                            </div>
                            <div className="items-center justify-between gap-5 sm:flex md:gap-20">
                                <label htmlFor="hrDefaultinput">ایمیل</label>
                                <input id="hrDefaultinput" type="email" placeholder="name@example.com"
                                       className="form-input" />
                            </div>
                            <div className="items-center justify-between gap-5 sm:flex md:gap-20">
                                <label htmlFor="hrSmallinput">ایمیل</label>
                                <input id="hrSmallinput" type="email" placeholder="name@example.com"
                                       className="form-input py-1.5 text-xs" />
                            </div>
                        </form>
                    </div>
                </PanelCodeHighlight>

                {/*  Readonly  */}
                <PanelCodeHighlight
                    title="فقط خواندن"
                    className="lg:row-start-[14]"
                >
                    <div className="mb-5">
                        <form>
                            <div>
                                <input type="text" placeholder="Readonly input here…"
                                       className="form-input disabled:pointer-events-none" readOnly />
                            </div>
                        </form>
                    </div>
                </PanelCodeHighlight>

                {/* Disabled */}
                <PanelCodeHighlight
                    title="غیرفعال"
                >
                    <div className="mb-5">
                        <form className="space-y-5">
                            <div>
                                <label htmlFor="disInput" className="text-white-dark">
                                    ورودی غیرفعال
                                </label>
                                <input
                                    id="disInput"
                                    type="text"
                                    placeholder="Readonly input here…"
                                    className="form-input cursor-not-allowed disabled:pointer-events-none disabled:bg-[#eee] dark:disabled:bg-[#1b2e4b]"
                                    disabled
                                />
                            </div>
                            <div>
                                <label htmlFor="disSelect" className="text-white-dark">
                                    ورودی غیرفعال
                                </label>
                                <select id="disSelect"
                                        className="form-select text-white-dark disabled:pointer-events-none disabled:bg-[#eee] dark:disabled:bg-[#1b2e4b]"
                                        disabled>
                                    <option>ورودی غیرفعال</option>
                                    <option>One</option>
                                    <option>Two</option>
                                    <option>Three</option>
                                </select>
                            </div>
                            <div>
                                <label className="flex items-center">
                                    <input type="checkbox" className="form-checkbox" disabled />
                                    <span className="text-white-dark">{`ورودی غیرفعال`}</span>
                                </label>
                            </div>
                            <button type="submit"
                                    className="btn btn-primary !mt-6 disabled:pointer-events-none disabled:opacity-60"
                                    disabled>
                                ارسال
                            </button>
                        </form>
                    </div>
                </PanelCodeHighlight>

                {/* Custom */}
                <PanelCodeHighlight
                    title="Checkboxes"
                >
                    <div className="mb-5">
                        <form>
                            <div>
                                <label className="flex cursor-pointer items-center">
                                    <input type="checkbox" className="form-checkbox" defaultChecked />
                                    <span className=" text-white-dark">Checkbox</span>
                                </label>
                            </div>
                        </form>
                    </div>
                </PanelCodeHighlight>

                <PanelCodeHighlight
                    title="Radio"
                >
                    <div className="mb-5">
                        <form className="space-y-5">
                            <div>
                                <label className="flex cursor-pointer items-center">
                                    <input type="radio" name="custom_radio2" className="form-radio" defaultChecked />
                                    <span className="text-white-dark">فعال</span>
                                </label>
                            </div>
                            <div>
                                <label className="flex cursor-pointer items-center">
                                    <input type="radio" name="custom_radio2" className="form-radio" />
                                    <span className="text-white-dark">غیرفعال</span>
                                </label>
                            </div>
                        </form>
                    </div>
                </PanelCodeHighlight>

                <PanelCodeHighlight
                    title="غیرفعال"
                >
                    <div className="mb-5">
                        <form className="space-y-5">
                            <div>
                                <label className="flex items-center">
                                    <input type="checkbox" className="form-checkbox" disabled />
                                    <span className=" text-white-dark">چک باکس</span>
                                </label>
                            </div>
                            <div>
                                <label className="flex items-center">
                                    <input type="radio" className="form-radio" disabled />
                                    <span className="text-white-dark"> radio</span>
                                </label>
                            </div>
                        </form>
                    </div>
                </PanelCodeHighlight>

                <PanelCodeHighlight
                    title="انتخاب"
                >
                    <div className="mb-5">
                        <form>
                            <div>
                                <select className="form-select text-white-dark">
                                    <option>لطفا انتخاب کنید</option>
                                    <option>One</option>
                                    <option>Two</option>
                                    <option>Three</option>
                                </select>
                            </div>
                        </form>
                    </div>
                </PanelCodeHighlight>

                <PanelCodeHighlight
                    title="چند انتخابی"

                >
                    <div className="mb-5">
                        <form>
                            <div>
                                <select size={4} multiple className="form-multiselect !bg-none text-white-dark">
                                    <option>لطفا انتخاب کنید</option>
                                    <option>One</option>
                                    <option>Two</option>
                                    <option>Three</option>
                                    <option>Four</option>
                                    <option>Five</option>
                                </select>
                            </div>
                        </form>
                    </div>
                </PanelCodeHighlight>
            </div>
        </div>
    );
}
